/*
	ExternalInterface test code for GNU Flash Player
	Written (2016) by Nutchanon Wetchasit <Nutchanon.Wetchasit@gmail.com>
	
	Released to public domain under Creative Commons Zero 1.0
	(https://creativecommons.org/publicdomain/zero/1.0/)
	
	Once this flash code is run, it will draw blue square
	on each corner of the screen. (Total three)
	
	Each square represents:
	- top-left:     availability of ExternalInterface
	- top-right:    success of adding ExternalInterface callback
	- bottom-left:  success of browser calling the ExternalInterface callback
	
	When each square changed to orange color, it signifies availability/success
	of the corresponding item.
	
	Expected Results*
	-----------------
	If this flash file is run under a standalone player (ExternalInterface is not available):
		blue   blue
		blue
	If this flash file is run directly under a web browser (ExternalInterface is available, but no callback is called):
		orange orange
		blue
	If this flash file is run under js2flash-objarg.html (ExternalInterface is available, and callback is called properly):
		orange orange
		orange
	
	* Tested using Adobe Flash standalone player 9.0.45.0,
	  Adobe Flash NPAPI plugin 11.3.300.271, Opera browser 11.51,
	  on Microsoft Windows XP SP3.

*/
import flash.external.*;

class JS2FlashObjectArg {
	public static var app:JS2FlashObjectArg;
	
	/* <init>: constructor, initialize callback */
	public function JS2FlashObjectArg() {
		trace("callee: starting");
		with(_root) {
			lineStyle(undefined,0x000000,100);
			moveTo(0, 0);
			beginFill(0x0066FF);
			lineTo(50,0);
			lineTo(50,50);
			lineTo(0,50);
			lineTo(0,0);
			endFill();
			
			moveTo(320, 0);
			beginFill(0x0066FF);
			lineTo(270,0);
			lineTo(270,50);
			lineTo(320,50);
			lineTo(320,0);
			endFill();
			
			moveTo(0,240);
			beginFill(0x0066FF);
			lineTo(50,240);
			lineTo(50,190);
			lineTo(0,190);
			lineTo(0,240);
			endFill();
		}
		
		if(!ExternalInterface.available) {
			trace("callee: ExternalInterface unavailable");
			return;
		}
		with(_root) {
			lineStyle(undefined,0x000000,100);
			moveTo(0, 0);
			beginFill(0xFF9900);
			lineTo(50,0);
			lineTo(50,50);
			lineTo(0,50);
			lineTo(0,0);
			endFill();
		}
		
		trace("callee: adding ExternalInterface callback");
		if(!ExternalInterface.addCallback("script_call",this,script_call)) {
			trace("callee: failed to add ExternalInterface callback");
		} else {
			with(_root) {
				lineStyle(undefined,0x000000,100);
				moveTo(320,0);
				beginFill(0xFF9900);
				lineTo(270,0);
				lineTo(270,50);
				lineTo(320,50);
				lineTo(320,0);
				endFill();
			}
		}
		
		trace("callee: finished initializing");
	}
	
	/* script_call(): ExternalInterface-based callback function */
	public function script_call(arg):Void {
		trace("callee: entering ExternalInterface callback");
		if(typeof(arg)=="object" && arg.a=="Hello" && arg.b=="World") {
			trace("callee: ExternalInterface callback succeeded, expected object with member [a=Hello, b=World] got object with [a=Hello, b=World]");
			with(_root) {
				lineStyle(undefined,0x000000,100);
				moveTo(0,240);
				beginFill(0xFF9900);
				lineTo(50,240);
				lineTo(50,190);
				lineTo(0,190);
				lineTo(0,240);
				endFill();
			}
		} else {
			trace("callee: ExternalInterface called incorrectly, expected object with member [a=Hello, b=World] got "+typeof(arg)+" with [a="+arg.a+", b="+arg.b+"]");
		}
		trace("callee: ExternalInterface callback finished");
	}
	
	/* main(): MTASC entry point */
	public static function main(mc:MovieClip):Void {
		app=new JS2FlashObjectArg();
	}
}
